==> conky_1.10.8.orig.tar.gz: conky-1.10.8/src/read_tcpip.h <==
/* -*- mode: c; c-basic-offset: 4; tab-width: 4; indent-tabs-mode: t -*-
 * vim: ts=4 sw=4 noet ai cindent syntax=c
 *
 * Conky, a system monitor, based on torsmo
 *
 * Any original torsmo code is licensed under the BSD license
 *
 * All code written since the fork of torsmo is licensed under the GPL
 *
 * Please see COPYING for details
 *
 * Copyright (c) 2004, Hannu Saransaari and Lauri Hakkarainen
 * Copyright (c) 2005-2012 Brenden Matthews, Philip Kovacs, et. al.
 *	(see AUTHORS)
 * All rights reserved.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef _READ_TCP_H
#define _READ_TCP_H

void parse_read_tcpip_arg(struct text_object *, const char *, void *);
void parse_tcp_ping_arg(struct text_object *obj, const char *arg, void *free_at_crash);
void print_read_tcp(struct text_object *, char *, int);
void print_read_udp(struct text_object *, char *, int);
void print_tcp_ping(struct text_object *, char *, int);
void free_read_tcpip(struct text_object *);
void free_tcp_ping(struct text_object *);

#endif /* _READ_TCP_H */

==> conky_1.11.6.orig.tar.gz: conky-1.11.6/src/read_tcpip.h <==
/*
 *
 * Conky, a system monitor, based on torsmo
 *
 * Any original torsmo code is licensed under the BSD license
 *
 * All code written since the fork of torsmo is licensed under the GPL
 *
 * Please see COPYING for details
 *
 * Copyright (c) 2004, Hannu Saransaari and Lauri Hakkarainen
 * Copyright (c) 2005-2019 Brenden Matthews, Philip Kovacs, et. al.
 *	(see AUTHORS)
 * All rights reserved.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef _READ_TCP_H
#define _READ_TCP_H

void parse_read_tcpip_arg(struct text_object *, const char *, void *);
void parse_tcp_ping_arg(struct text_object *obj, const char *arg,
                        void *free_at_crash);
void print_read_tcp(struct text_object *, char *, unsigned int);
void print_read_udp(struct text_object *, char *, unsigned int);
void print_tcp_ping(struct text_object *, char *, unsigned int);
void free_read_tcpip(struct text_object *);
void free_tcp_ping(struct text_object *);

#endif /* _READ_TCP_H */
